@@ -10,7 +10,7 @@ after log => sub {
 
     my %logargs = (
        sha1   => $c->stash->{Commit}->sha1, # $commit->sha1
-       count  => 25, #Gitalist->config->{paging}{log} || 25,
+       count  => Gitalist->config->{paging}{log} || 25,
     );
 
     my $page = $c->req->param('pg') || 0;
